@@ -55,12 +55,13 @@ class Target():
 
     def validate(self):
         if self.name:
-            name_pattern = r'^[A-Za-z0-9_]+$'
-            if not re.match(name_pattern, self.name):
+            p = r'(?:^[A-Za-z0-9][A-Za-z0-9_:]*[A-Za-z0-9]$|^[A-Za-z0-9]$)'
+            if not re.match(p, self.name):
                 raise RunfileFormatError(
-                    f'Target name "{self.name}" '
-                    'can only contain alphanumeric characters and '
-                    'underscores.')
+                    f'Invalid target name "{self.name}". Target names may '
+                    'only contain alphanumeric characters, underscores, and '
+                    'colons. Trailing underscores or colons are not '
+                    'permitted.')
 
     def execute(self, silent=False):
         self.result = TargetResult(self.unique_name)
@@ -80,18 +81,13 @@ class Target():
             else:
                 self.container = self.runfile.container()
 
-        if not self.blocks:
-            if self.config and self.name:
-                # Technically, we executed the config, so mark success
-                self.result.set_status(TargetResult.SUCCESS)
-            return self.result
-
         if not self.is_expired():
             self.result.set_status(TargetResult.CACHED)
             return self.result
 
-        style = MsgType.CONTAINER if self.container else MsgType.WORKING
-        msg(f'Running {self.unique_name}...', style)
+        if self.blocks:
+            style = MsgType.CONTAINER if self.container else MsgType.WORKING
+            msg(f'Running {self.unique_name}...', style)
 
         try:
             for block in self.blocks:
@@ -208,7 +204,11 @@ class Target():
                     'mode': 'rw'
                 },
                 '/tmp': {
-                    'bind': '/mnt/tmp',
+                    'bind': '/host/tmp',
+                    'mode': 'rw'
+                },
+                '/var/folders': {
+                    'bind': '/host/var/folders',
                     'mode': 'rw'
                 }
             }
